@@ -3,6 +3,9 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
 
 #include <termios.h>
 
@@ -65,7 +68,7 @@ QVreset(sdcInfo info, int flag) {
     /*supposed to be 0x5c('Z') or 0x69*/
     if (casio_qv_read(info, &c, 1) == SDC_FAIL) return(-1);
 
-#if !defined(__FreeBSD__)  /* Why ? */
+#if !defined(BSD)  /* Why ? */
     if (!casio_qv_confirm_checksum(info, c)) {
 	print_error(CHECKSUM_FAILED, "QVreset");
 	return(-1);
@@ -766,7 +769,7 @@ casioSetPortSpeed(sdcInfo info, int speed) {
     switch(speed) {
 	case LIGHT:			/* 115200 baud */
 	    n = 3;
-#if defined(WIN32) || defined (OS2) || defined(__FreeBSD__) || defined(DOS) || defined(__linux__)
+#if defined(WIN32) || defined (OS2) || defined(BSD) || defined(DOS) || defined(__linux__)
 	    baud = B115200;
 #else
 	    baud = B38400;
@@ -775,7 +778,7 @@ casioSetPortSpeed(sdcInfo info, int speed) {
 
 	case TOP:			/* 57600 baud */
 	    n = 7;
-#if defined(WIN32) || defined(OS2) || defined(__FreeBSD__) || defined(DOS) || defined(__linux__)
+#if defined(WIN32) || defined(OS2) || defined(BSD) || defined(DOS) || defined(__linux__)
 
 	    baud = B57600;
 #else
