@@ -1,17 +1,21 @@
 /*
- * $Id: fujilib.c,v 1.13.2.1 1999/10/23 02:54:53 mmartin Exp $
+ * $Id: fujilib.c,v 1.19 2000/01/11 02:13:33 mmartin Exp $
  
- Fuji Camera library for the gphoto project, 1999 Matthew G. Martin
-  This routine works for DS-7 .  Don't know about any others.
+ Fuji Camera library for the gphoto project, 
+ (C) 2000 Matthew G. Martin <matt.martin@ieee.org>
+  This routine works for Fuji DS-7 and DX-5,7,10 and MX-500,600,700,2700, 
+  Apple QuickTake 200,Samsung Kenox SSC-350N cameras and possibly others.
 
-  Reworked from the "fujiplay" package:
+   Preview and take_picture fixes and preview conversion integrated 
+   by Michael Smith <michael@csuite.ns.ca>.
+
+   This driver was reworked from the "fujiplay" package:
       * A program to control Fujifilm digital cameras, like
       * the DS-7 and MX-700, and their clones.
-      *
       * Written by Thierry Bousch <bousch@topo.math.u-psud.fr>
       * and released in the public domain.
 
-    Portions of this code were adapted taken from
+    Portions of this code were adapted from
     GDS7 v0.1 interactive digital image transfer software for DS-7 camera
     Copyright (C) 1998 Matthew G. Martin
 
@@ -52,8 +56,6 @@
 #include "../src/util.h"
 #include "../src/callbacks.h"
 
-/*#include "blank.xpm"*/
-
 extern unsigned char *fuji_exif_convert(exifparser *exifdat);
 extern GtkWidget *open_fuji_config_dialog();
 
@@ -70,6 +72,15 @@ extern GtkWidget *open_fuji_config_dialog();
 #define B115200 EXTB
 #endif
 
+#define STX 0x2  /* Start of data */
+#define ETX 0x3  /* End of data */
+#define EOT 0x4  /* End of session */
+#define ENQ 0x5  /* Enquiry */
+#define ACK 0x6
+#define ESC 0x10
+#define ETB 0x17 /* End of transmission block */
+#define NAK 0x15
+
 struct pict_info {
 	char *name;
 	int number;
@@ -81,7 +92,6 @@ struct pict_info {
 int fuji_initialized=0; 
 int fuji_count;
 int fuji_size;
-int fuji_piccount;       /* For unique filename to Defeat the ImLib Cache */
 int devfd = -1;
 int maxnum;
 int fuji_debug=0;
@@ -183,6 +193,7 @@ int put_byte (int c)
 	return put_bytes(1, buff);
 }
 
+/* See if camera is "there" */
 int attention (void)
 {
 	int i;
@@ -191,8 +202,8 @@ int attention (void)
 	while (get_byte() >= 0)
 		continue;
 	for (i = 0; i < 3; i++) {
-		put_byte(0x05);
-		if (get_byte() == 0x06)
+		put_byte(ENQ);
+		if (get_byte() == ACK)
 			return 0;
 	}
 	update_status("The camera does not respond.");
@@ -204,24 +215,24 @@ void send_packet (int len, unsigned char *data, int last)
 	unsigned char *p, *end, buff[3];
 	int check;
 
-	last = last ? 0x03 : 0x17;
+	last = last ? ETX : ETB;
 	check = last;
 	end = data + len;
 	for (p = data; p < end; p++)
 		check ^= *p;
 
 	/* Start of frame */
-	buff[0] = 0x10;
-	buff[1] = 0x02;
+	buff[0] = ESC;
+	buff[1] = STX;
 	put_bytes(2, buff);
 
 	/* Data */
 	for (p = data; p < end; p++)
-		if (*p == 0x10) {
+		if (*p == ESC) {
 			/* Escape the last character */
 			put_bytes(p-data+1, data);
 			data = p+1;
-			put_byte(0x10);
+			put_byte(ESC);
 		}
 	put_bytes(end-data, data);
 
@@ -236,7 +247,7 @@ int read_packet (void)
 	unsigned char *p = answer;
 	int c, check, incomplete;
 
-	if (get_byte() != 0x10 || get_byte() != 0x02) {
+	if (get_byte() != ESC || get_byte() != STX) {
 bad_frame:
 		/* drain input */
 		while (get_byte() >= 0)
@@ -247,11 +258,11 @@ bad_frame:
 	while(1) {
 		if ((c = get_byte()) < 0)
 			goto bad_frame;
-		if (c == 0x10) {
+		if (c == ESC) {
 			if ((c = get_byte()) < 0)
 				goto bad_frame;
-			if (c == 0x03 || c == 0x17) {
-				incomplete = (c == 0x17);
+			if (c == ETX || c == ETB ) {
+				incomplete = (c == ETB);
 				break;
 			}
 		}
@@ -278,6 +289,8 @@ int cmd (int len, unsigned char *data)
 	int i, c, timeout=50;
 	fuji_count=0;
 
+	if (fuji_debug) fprintf(stderr,"cmd %d\n",data[1]);
+
 	/* Some commands require large timeouts */
 	switch (data[1]) {
 	  case 0x27:	/* Take picture */
@@ -294,11 +307,14 @@ int cmd (int len, unsigned char *data)
 		send_packet(len, data, 1);
 		wait_for_input(timeout);
 		c = get_byte();
-		if (c == 0x06)
+
+		if (c == ACK )
 			goto rd_pkt;
-		if (c != 0x15){
-			if(attention()) return(-1);
-		};
+		if (c == NAK) return (-1); /* NAK=Unrecognized command */
+
+		/* Make sure camera is still alive */
+		if(attention()) return(-1);
+
 	}
 	update_status( "Cannot issue command, aborting.");
 	return(-1);
@@ -306,15 +322,15 @@ rd_pkt:
 	wait_for_input(timeout);
 
 	for (i = 0; i < 3; i++) {
-		if (i) put_byte(0x15);
+		if (i) put_byte(NAK);
 		c = read_packet();
 		if (c < 0)
 			continue;
 		if (c && interrupted) {
 			fprintf(stderr, "\nInterrupted!\n");
-			exit(1);
+			return -1;
 		}
-		put_byte(0x06);
+		put_byte(ACK);
 		if (fuji_buffer != NULL) {
 		  if ((fuji_count+answer_len-4)<fuji_maxbuf){
 		    memcpy(fuji_buffer+fuji_count,answer+4,answer_len-4);
@@ -335,7 +351,7 @@ rd_pkt:
 		return 0;
 	}		
 	fprintf(stderr, "Cannot receive answer, aborting.\n");
-	return(-1);
+	return -1;
 }
 
 int cmd0 (int c0, int c1)
@@ -481,11 +497,15 @@ void get_command_list (void)
 {
 	int i;
 
+	/* Set all commands as unsupported */
 	memset(has_cmd, 0, 256);
+
+	/* Attempt to fetch supported list */
 	if (cmd0 (0, 0x4c)) return ;
+
+	/* Note supported commands if list was returned */
 	for (i = 4; i < answer_len; i++)
 	  has_cmd[answer[i]] = 1;
-	/*		has_cmd[i] = 1;*/
 }
 
 int get_picture_info(int num,char *name){
@@ -556,30 +576,41 @@ void list_pictures (void)
 
 void close_connection (void)
 {
-	put_byte(0x04);
+	put_byte(EOT);
 	tcdrain(devfd);
 	usleep(50000);
 }
 
 void reset_serial (void)
 {
+        if (fuji_debug) fprintf(stderr,"Fujilib:Reset Serial\n");
 	if (devfd >= 0) {
 		close_connection();
 		tcsetattr(devfd, TCSANOW, &oldt);
+		close(devfd);
 	}
 	devfd = -1;
 }
 
 int init_serial (const char *devname)
 {
-	devfd = open(devname, O_RDWR|O_NOCTTY);
-	if (devfd < 0) {
-		perror("Cannot open device");
-		exit(1);
+        /* Attempt to open the serial device*/
+        if (devfd<0) {
+                if (fuji_debug) 
+		        fprintf(stderr,"Fujilib:Opening Serial Device\n");
+
+		devfd = open(devname, O_RDWR|O_NOCTTY);
+
+		if (devfd < 0) { /* Open didn't work */
+		        fprintf(stderr,"Fujilib:Cannot open device %s\n",\
+				devname);
+		        return -1;
+		}
 	}
+
 	if (tcgetattr(devfd, &oldt) < 0) {
-		perror("tcgetattr");
-		exit(1);
+	        fprintf(stderr,"Fujilib:tcgetattr error %s\n",devname);
+	        return -1;
 	}
 	newt = oldt;
 	newt.c_iflag |= (PARMRK|INPCK);
@@ -592,11 +623,12 @@ int init_serial (const char *devname)
 	newt.c_cc[VTIME] = 1;
 	cfsetispeed(&newt, B9600);
 	cfsetispeed(&newt, B9600);
+
 	if (tcsetattr(devfd, TCSANOW, &newt) < 0) {
-		perror("tcsetattr");
-		exit(1);
+	        fprintf(stderr,"Fujilib:tcgetattr error %s\n",devname);
+		return -1;
 	}
-	atexit(reset_serial);
+
        return(attention());
 }
 
@@ -604,6 +636,10 @@ void set_max_speed (void)
 {
 	int speed;
 
+	if (fuji_debug)
+	        fprintf(stderr,"Setting max speed\n");
+
+	/* This mess could be cleaned up... */
 #ifdef B115200
 	speed = B115200;
 	cmd1(1, 7, 8);
@@ -630,15 +666,18 @@ change_speed:
 	cfsetospeed(&newt, speed);
 	tcsetattr(devfd, TCSANOW, &newt);
 	attention();
+	if (fuji_debug)
+	        fprintf(stderr,"Speed Upgraded\n");
+
 }
 
 int download_picture(int n,int thumb,struct Image *im)
 {
 	char name[100];
-	/*	int size;*/
 	struct stat st;
 	clock_t t1, t2;
 
+	/* Predict picture size */
 	if (!thumb) {
 	        fuji_size=get_picture_info(n,name);
 		if (fuji_debug) fprintf(stderr,"%3d   %12s  \n", n, name);
@@ -646,7 +685,7 @@ int download_picture(int n,int thumb,struct Image *im)
 	else fuji_size=10500;  /* Probly not same for all cams, better way ? */
 	
 	t1 = times(0);
-	if (cmd2(0, (thumb?0:0x02), n/*,fuji_buffer*/)==-1) goto die_gracefully;
+	if (cmd2(0, (thumb?0:0x02), n)==-1) goto die_gracefully;
 
 	if (fuji_debug) fprintf(stderr,
 		"Download %s:%4d actual bytes vs expected %4d bytes\n", 
@@ -767,12 +806,12 @@ int upload_pic (const char *picname)
 		}
 		if (!last && interrupted) {
 			fprintf(stderr, "Interrupted!\n");
-			exit(1);
+			return 0;
 		}
 again:
 		send_packet(4+len, buffer, last);
 		wait_for_input(1);
-		if (get_byte() == 0x15)
+		if (get_byte() == NAK)
 			goto again;
 	}
 	fclose(fd);
@@ -782,39 +821,18 @@ again:
 
 
 int fuji_init(){
-        char idstring[256];
+	
+        if (! fuji_initialized)  /* this should never happen...*/
+	        if (fuji_initialize()<1) return -1;
 
-	if (fuji_debug) printf("Initializing %s\n",serial_port);
-
-	fuji_maxbuf=FUJI_MAXBUF_DEFAULT; /* This should be camera dependent */
-	/*	read_fuji_config(); */
+	if (fuji_debug) 
+	        fprintf(stderr,"Fujilib:Initializing %s\n",serial_port);
 
 	if (init_serial(serial_port)==-1) return(-1);
 
 	set_max_speed();
 
-	if (!fuji_initialized){
-	  fuji_buffer=malloc(fuji_maxbuf);
-	  if (fuji_buffer==NULL) {
-	    fprintf(stderr,"Memory allocation error\n");
-	    return(-1);
-	  } else if (/*fuji_debug*/1) {
-	    fprintf(stderr,"Allocated %ld bytes to main buffer\n",fuji_maxbuf);
-	  };
-	  
-	  /* could ID camera here and set the relevent variables... */
-	        get_command_list();
-	  /* For now assume that the user wil not use 2 different fuji cams
-	     in one session */
-	        strcpy(idstring,"Identified ");
-	        strncat(idstring,dc_version_info(),100);
-	        update_status(idstring);
-
-	  /* load_fuji_options() */
-	        fuji_initialized=1;  
-	};
-
-    return(0);
+	return(0);
 };
 
 
@@ -835,7 +853,7 @@ int fuji_configure(){
 
 struct Image *fuji_get_picture (int picture_number,int thumbnail){
   GdkImlibImage *imlibimage;
-  char rm[1024],tmpfname[1024];
+  char tmpfname[1024];
   unsigned char *buffer;
   struct Image *newimage;
   FILE *fd;
@@ -846,25 +864,19 @@ struct Image *fuji_get_picture (int picture_number,int thumbnail){
   if (fuji_debug) fprintf(stderr,"fuji_get_picture called for #%d %s\n",
 			  picture_number, thumbnail?"thumb":"photo");
 
-  if (fuji_init()) return(0);/*goto bugout*/;
+  if (fuji_init()) return(0);
 
+  /* setup gdk_image buffer */
   newimage=malloc(sizeof(struct Image));
   newimage->image=NULL;
 
-  if (thumbnail)
-    sprintf(tmpfname, "%s/gphoto-thumbnail-%i-%i.jpg",
-	    gphotoDir, getpid(),fuji_piccount);
-  else {
-    sprintf(tmpfname, "%s/gphoto-%i-%i.jpg", 
-	    gphotoDir, getpid(), fuji_piccount);
-  };
-  fuji_piccount++;
-
   if (download_picture(picture_number,thumbnail,newimage)) {
+    /* No Luck */
     free(newimage);
     return(0);
   };
 
+  /* Point to the actual downloaded data */
   buffer=newimage->image;
 
   /* Work on the tags...*/
@@ -882,15 +894,17 @@ struct Image *fuji_get_picture (int picture_number,int thumbnail){
     };
     newimage->image_info_size=exifdat.ifdtags[thumbnail?1:0]*2;
 
-    if (thumbnail) {/* This SHOULD be done by tag id */
+    if (thumbnail) {/* SHOULD be done by tag id rather than assuming order*/
       togphotostr(&exifdat,0,0,newimage->image_info,newimage->image_info+1);
       togphotostr(&exifdat,0,1,newimage->image_info+2,newimage->image_info+3);
       togphotostr(&exifdat,0,2,newimage->image_info+4,newimage->image_info+5);
       newimage->image_info_size+=6;
     };
-
+    
+    /* Grab all of the tags */
     exif_add_all(&exifdat,thumbnail?1:0,newimage->image_info+(thumbnail?6:0));
 
+    /* Spew a list of the tags, more than you will ever need */
     if (fuji_debug) {
             printf("====================EXIF TAGS================\n");
 	    for(i=0;i<newimage->image_info_size/2;i++)
@@ -908,7 +922,7 @@ struct Image *fuji_get_picture (int picture_number,int thumbnail){
 	
 	fprintf(stderr,"Thumbnail conversion error, saving data to \
 fuji-death-dump.dat\n\
-\tPlease mail this file to Matt.Martin@ieee.org along with a description \
+\tPlease mail this file to gphoto-devel@gphoto.org along with a description \
 of setup, camera model and any text output.\n");
 	if ((fp=fopen("fuji-death-dump.dat","w"))!=NULL){
 	  fwrite(buffer,1,newimage->image_size,fp);
@@ -935,13 +949,6 @@ of setup, camera model and any text output.\n");
   reset_serial(); /* Wish this wasn't necessary...*/
   return(newimage);
 
-  /*
-bugout:
-  imlibimage = gdk_imlib_create_image_from_xpm_data(blank_xpm);
-  newimage->image=(char *)blank_xpm;
-  reset_serial();
-  return(newimage);
-*/
 };
 
 int fuji_delete_image (int picture_number){
@@ -964,6 +971,8 @@ int fuji_delete_image (int picture_number){
 int fuji_number_of_pictures (){
   int numpix;
 
+  if (fuji_debug) fprintf(stderr, "Fujilib:Number of Pictures Called\n");
+
   if (fuji_init()) return (-1);
   numpix=dc_nb_pictures();
 
@@ -972,39 +981,174 @@ int fuji_number_of_pictures (){
 
 };
 
+/* 
+   One-time initialization: Read config, allocate buffers, etc
+ */
 int fuji_initialize () {
+        char idstring[256];
 
+	fuji_maxbuf=FUJI_MAXBUF_DEFAULT; /*Should be camera dependent*/
+	/*	read_fuji_config(); */
+
+	if (fuji_debug) fprintf(stderr,"Fujilib: Doing First Init\n");
+
+	/* Allocate photo buffer */
+	if (fuji_buffer) free(fuji_buffer);
+	fuji_buffer=malloc(fuji_maxbuf);
+	if (fuji_buffer==NULL) {
+	        fprintf(stderr,"Fujilib:Memory allocation error\n");
+		return(-1);
+	} else if (fuji_debug) {
+	        fprintf(stderr,"Fujilib:Allocated %ld bytes to main buffer\n",\
+			fuji_maxbuf);
+	};
+	fuji_initialized=1;  
+	atexit(reset_serial);
+
+	/* Setup the serial port*/
+	if (fuji_init()) {
+	        fuji_initialized=0;
+		return(-1);
+	};
+	
+	/* could ID camera here and set the relevent variables... */
+	get_command_list();
+	/* Assume the user won't use 2 diff fuji cams in one session */
+	strcpy(idstring,"Identified ");
+	strncat(idstring,dc_version_info(),100);
+	update_status(idstring);
+	if (fuji_debug) fprintf (stderr,"Fujilib:%s\n",idstring);
+
+	reset_serial();
 	return 1;
 }
+ 
+
+/* Convert Fuji previews to 24-bit PPM format.
+ * Based on yycc2ppm.c, part of the fujiplay package by Thierry Bousch
+ * <bousch@club-internet.fr>.
+ *
+ * > One question - what format is the output from "fujiplay preview"?
+ *
+ * I don't think it's a "standard" format, rather a custom one. See the
+ * yycc2ppm(1) utility for more information: there is a four-byte header
+ * containing the image dimensions, followed by chunks of 4 bytes. Each
+ * chunk encodes two adjacent pixels, in the format Y1 Y2 Cb Cr, where Y1
+ * and Y2 are the luminance values of the two pixels, and Cb and Cr are the
+ * averaged blue and red chrominance values for the pair.
+ *
+ * Usage: Pass the data, the length, and a pointer to an integer to receive
+ *	  the size of the PPM buffer.
+ * Returns the new PPM buffer.
+ */
+static char *
+yycc2ppm(unsigned char *c, int len, int *ppmsize)
+{
+	int width, height, Y1, Y2, Cb, Cr, Roff, Goff, Boff;
+	const char *headformat = "P6\n%d %d\n255\n";
+	char header[24];
+	unsigned char *ppm;
+	register int i, j;
+
+	if (len < 8) {
+		fprintf(stderr, "yycc2ppm: preview is %d bytes, need >= 8.\n",
+			len);
+		return NULL;
+	}
+	width  = 256 * c[1] + c[0];	/* little-endian */
+	height = 256 * c[3] + c[2];
+
+	if (fuji_debug)
+		fprintf(stderr, "yycc2ppm: preview %d x %d\n", width, height);
+
+	snprintf(header, sizeof(header), headformat, width, height);
+	header[sizeof(header)-1] = '\0';
+
+	/* For every four bytes of YYCC after the header, generate 6 of RGB */
+	*ppmsize = strlen(header) + 6 * (len - 4) / 4;
+
+	ppm = malloc(*ppmsize);
+	if (!ppm) {
+		fprintf(stderr,"yycc2ppm: couldn't alloc %d bytes\n",*ppmsize);
+		return NULL;
+	}
+	strcpy(ppm, header);
+
+	for (i=4, j=strlen(header); i<len; i+=4) {
+		Y1 = c[i];
+		Y2 = c[i+1];
+		Cb = c[i+2] - 128;
+		Cr = c[i+3] - 128;
+
+		Roff = (359*Cr + 128) >> 8;
+		Goff = (-88*Cb - 183*Cr + 128) >> 8;
+		Boff = (454*Cb + 128) >> 8;
+
+		#define CLIP(x) (((x)<0) ? 0 : (((x)>255) ? 255 : (x)))
+		ppm[j++] = CLIP(Y1+Roff);
+		ppm[j++] = CLIP(Y1+Goff);
+		ppm[j++] = CLIP(Y1+Boff);
+		ppm[j++] = CLIP(Y2+Roff);
+		ppm[j++] = CLIP(Y2+Goff);
+		ppm[j++] = CLIP(Y2+Boff);
+	}
+
+	if (i != len)
+		fprintf(stderr, "yycc2ppm: warn: preview had %d extra bytes.\n",
+			i - len);
+	return ppm;
+}
+
 
 struct Image *fuji_get_preview (){
-  char tmpfname[1024],rm[1024];
   FILE *fd;
 
   struct Image *newimage;
 
+  if (fuji_init()) return NULL;
+
   newimage=malloc(sizeof( struct Image));
+  if (!newimage) {
+    fprintf(stderr, "fuji_get_preview: failed to malloc newimage.\n");
+    return NULL;
+  }
+  memset(newimage, 0, sizeof(struct Image));
 
   if (!has_cmd[0x62] || !has_cmd[0x64]) {
-    update_status("Cannot preview (unsupported command)\n");
-    /*    newimage->image=(char *)blank_xpm;*/
+    update_status("Cannot preview (unsupported command)");
     return ( 0 );
   }
 
   cmd0(0, 0x64);
   cmd0(0, 0x62);
-  newimage->image=malloc(fuji_count); /* What a hack!!!*/
-  memcpy(newimage->image,fuji_buffer,fuji_count);
+  newimage->image = yycc2ppm(fuji_buffer, fuji_count, &(newimage->image_size));
 
+  reset_serial();
+
+  if (!newimage->image) {
+    free(newimage);
+    return NULL;
+  }
+
+  strcpy(newimage->image_type, "ppm");
   return(newimage);
 };
 
 int fuji_take_picture (){
-  if (!has_cmd[0x62] || !has_cmd[0x64]) {
+   int pic;
+
+   if (fuji_init()) return (-1);
+
+   if (!has_cmd[0x27]) {
     update_status("Cannot take picture (unsupported command)\n");
     return(0);
   }
-  return(  take_picture());
+
+  pic=take_picture();
+
+  reset_serial();
+
+  return pic;
 };
 
 char *fuji_summary() {
@@ -1013,14 +1157,14 @@ char *fuji_summary() {
 
 char *fuji_description() {
 	return(
-"Fuji DS-7
+"Generic Fuji
 Matthew G. Martin
 Based on fujiplay by
 Thierry Bousch<bousch@topo.math.u-psud.fr>
 
-Known to work with Fuji DS-7, Apple QuickTake 200,
-Samsung Kenox SSC-350N cameras, but 
-may support other Fuji cams as well.");
+Known to work with Fuji DS-7 and DX-5,7,10 and MX-500,600,700,2700
+, Apple QuickTake 200,Samsung Kenox SSC-350N cameras, 
+but may support other Fuji cams as well.");
 }
 
 struct _Camera fuji = {fuji_initialize,
