@@ -16,12 +16,14 @@
  *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "config.h"
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef __FreeBSD__
-#include <sys/types.h>
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
 #endif
+#include <sys/types.h>
 #include <netinet/in.h>
 
 #include "kodak_generic.h"
