@@ -84,10 +84,17 @@ typedef enum
 static char *PortLabel[] = 
 {
    "Autodetect",
+#ifdef __NetBSD__
+   "/dev/tty00",
+   "/dev/tty01",
+   "/dev/tty02",
+   "/dev/tty03"
+#else
    "/dev/ttyS0",
    "/dev/ttyS1",
    "/dev/ttyS2",
    "/dev/ttyS3"
+#endif
 };
 /*---------------------------------------------------------------------*
  *                                                                     *
@@ -602,4 +609,3 @@ static void showCameraClock(void)
    gtk_label_set_text(GTK_LABEL(clockLabel), "new clock value");
    gtk_widget_show(clockLabel);
 }
-
