@@ -1,7 +1,7 @@
 #ifndef _QM100_DEFS_H
 #define _QM100_DEFS_H
-#define QM100_MOD      "1999/08/15"
-#define QM100_VER      "0.4.0"   
+#define QM100_MOD      "1999/12/26"
+#define QM100_VER      "0.4.0d"   
 
 /*---------------------------------------------------------------------*
  *                                                                     *
@@ -79,7 +79,11 @@
 #define WHITEBAL      packet.packet[32]
 #define PICNUM        packet.packet+0xf9
 
+#ifdef __NetBSD__
+#define DEFAULT_PORT	   "/dev/tty00"
+#else
 #define DEFAULT_PORT	   "/dev/ttyS0"
+#endif
 #define DEFAULT_SPEED   "57600"
 #define DEFAULT_PACING  "1"
 #define DEFAULT_TRACE   "Off"
