@@ -1,5 +1,6 @@
 #ifndef  _QM100_H
 #define  _QM100_H
+#include "config.h"
 #include <fcntl.h>
 #include <setjmp.h>
 #include <stdio.h>
@@ -8,6 +9,9 @@
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/types.h>
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
 #include <termios.h>
 #include <unistd.h>
 #include <errno.h>
