@@ -6,7 +6,7 @@ int dimage_v_open(char* dimage_v_device)
 	int fd=-1, errorlen=0;
 	char *errormsg, *buffer;
 
-    #ifdef __FreeBSD__
+    #ifdef BSD
     fd = open(dimage_v_device, O_RDWR|O_NOCTTY);
     #else
     fd = open(dimage_v_device, O_RDWR|O_NOCTTY|O_SYNC);
