@@ -17,6 +17,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
+
 #include "config.h"
 #include "gphoto.h"
 #include "main.h"
@@ -30,8 +34,8 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-#include "post_processing_on.xpm"
-#include "post_processing_off.xpm"
+#include "icons/post_processing_on.xpm"
+#include "icons/post_processing_off.xpm"
 
 #define DEBUG(x) printf(x)
 
@@ -93,9 +97,7 @@ void set_camera (char *model) {
 		    if (!command_line_mode)
 			gtk_label_set(GTK_LABEL(library_name),
 				      cameras[i].name);
-		    else 
-			printf("set_camera: %s\n", cameras[i].name);
-		    
+
 		    Camera = cameras[i].library;
 
 		    if ((*Camera->initialize)() != 0) {
@@ -131,14 +133,14 @@ void takepicture_call() {
 	}
 	    
 	appendpic(picNum, 0, TRUE, NULL);
-	sprintf(status, "New picture is #%i", picNum);
+	sprintf(status, "New picture is #%03i", picNum);
 	gtk_notebook_set_page (GTK_NOTEBOOK(notebook), picNum);
 	update_status(status);
 }
 
 void format (GtkWidget *dialog, GtkObject *button) {
 
-        gint current, no_pics, i;
+        gint no_pics, i;
         char error[32];
 
 	no_pics = (*Camera->number_of_pictures)();
@@ -266,6 +268,7 @@ void savepictodisk (gint picNum, gint thumbnail, char *prefix) {
 	struct Image *im = NULL; 
 	char fname[1024], error[32], process[1024];
 
+#if 0
 	struct ImageMembers *node = &Images;
 
 	if (!thumbnail) {
@@ -273,11 +276,12 @@ void savepictodisk (gint picNum, gint thumbnail, char *prefix) {
 		  atoi(node->info)!=picNum)  /*should be strtol. RAA*/
 		node = node->next;
 	    sprintf(fname, "%s.%s", prefix, "jpg");
-	    if (node != NULL) { /*A match was found*/
+	    if (node != NULL && node->info!=NULL) { /*A match was found*/
 		gdk_imlib_save_image(node->imlibimage, fname, NULL);
 		return;
 	    }
 	}
+#endif
 
 	if ((im = (*Camera->get_picture)(picNum, thumbnail)) == 0) {
 		sprintf(error, "Could not save #%i", picNum);
@@ -362,16 +366,16 @@ void saveselectedtodisk (GtkWidget *widget, char *type) {
                 node = node->next; i++;
                 if (GTK_TOGGLE_BUTTON(node->button)->active) {
 			if ((strcmp("i", type)==0)||(strcmp("in", type)==0)) {
-				sprintf(status, "Saving Image #%i...", i);
+				sprintf(status, "Saving Image #%03i...", i);
 				update_status(status);
-				sprintf(fname, "%s-%i",
-					saveselectedtodisk_dir, pic);
+				sprintf(fname, "%s-%03i",
+					saveselectedtodisk_dir, i);
 				savepictodisk(i, 0, fname); }
 			   else {
-				sprintf(status, "Saving Thumbnail #%i...", i);
+				sprintf(status, "Saving Thumbnail #%03i...", i);
 				update_status(status);
-				sprintf(fname, "%s-thumbnail-%i",
-					saveselectedtodisk_dir, pic);
+				sprintf(fname, "%s-thumbnail-%03i",
+					saveselectedtodisk_dir, i);
 				savepictodisk(i, 1, fname);
 			}
 			pic++;
@@ -417,7 +421,7 @@ void appendpic (gint picNum, gint thumbnail, gint fromCamera, char *fileName) {
 							im->image_size);
 		free_image(im);
 		if (post_process) {
-			sprintf(imagename, "%s/gphoto-image-%i.jpg",
+			sprintf(imagename, "%s/gphoto-image-%03i.jpg",
 				gphotoDir, picNum);
 			gdk_imlib_save_image(node->imlibimage,
 				imagename, NULL);
@@ -476,6 +480,20 @@ gint delete_event (GtkWidget *widget, GdkEvent *event, gpointer data) {
 /* Callbacks -------------------------------------------------
    ----------------------------------------------------------- */
 
+void port_dialog_tester(GtkWidget *entry, GtkWidget *label) {
+  int i=0;
+  char model[60];
+  
+  sprintf (model, "%s", gtk_entry_get_text(GTK_ENTRY(entry)));
+  while (strlen(cameras[i].name) > 0) {
+    if (strcmp(model, cameras[i].name) == 0) { 
+      gtk_label_set_text(GTK_LABEL(label),
+			 cameras[i].tester);
+      return;
+    } 
+    i++;
+  }
+}
 
 void port_dialog_update(GtkWidget *entry, GtkWidget *label) {
 
@@ -486,8 +504,8 @@ void port_dialog_update(GtkWidget *entry, GtkWidget *label) {
 
 	while (strlen(cameras[i].name) > 0) {
                 if (strcmp(model, cameras[i].name) == 0) {
-			gtk_label_set_text(GTK_LABEL(label),
-			(*cameras[i].library->description)());
+		       gtk_label_set_text(GTK_LABEL(label),
+					   (*cameras[i].library->description)());
 			return;
                 }
 		i++;
@@ -497,9 +515,9 @@ void port_dialog_update(GtkWidget *entry, GtkWidget *label) {
 
 void port_dialog() {
 
-	GtkWidget *dialog, *label, *button, *cbutton;
-	GtkWidget *port0, *port1, *port2, *port3, *other, *ent_other;
-	GtkWidget *hbox, *vbox, *vseparator;
+	GtkWidget *dialog, *label, *button, *cbutton, *betalabel;
+	GtkWidget *port0, *port1, *port2, *port3, *other, *ent_other, *tester;
+	GtkWidget *hbox, *vbox, *vseparator, *hseparator;
 	GtkWidget *combo, *description;
 	GSList *group;
 	GList *list;
@@ -511,7 +529,7 @@ void port_dialog() {
 
 #ifdef linux
         sprintf(serial_port_prefix, "/dev/ttyS");
-#elif defined(__FreeBSD__) || defined(__NetBSD__)
+#elif defined(BSD)
         sprintf(serial_port_prefix, "/dev/tty0");
 #else
         sprintf(serial_port_prefix, "/dev/tty0");
@@ -526,8 +544,7 @@ void port_dialog() {
 	/* Box going across the dialog... */
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_widget_show(hbox);
-	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox),
-					hbox);
+	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox),hbox);
 
 	/* For the camera selection... */
 	vbox = gtk_vbox_new(FALSE, 0);
@@ -567,6 +584,23 @@ void port_dialog() {
 
 	port_dialog_update(GTK_COMBO(combo)->entry, description);
 
+	betalabel = gtk_label_new("\ngPhoto user(s) that reported this model:\n");
+	gtk_label_set_justify(GTK_LABEL(betalabel), GTK_JUSTIFY_LEFT);
+	gtk_widget_show(betalabel);
+	
+ 	gtk_box_pack_start(GTK_BOX(vbox), betalabel, FALSE, TRUE, 0);
+
+	tester = gtk_label_new ("");
+	gtk_widget_show(tester);
+	gtk_label_set_justify(GTK_LABEL(tester), GTK_JUSTIFY_LEFT);
+	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),
+		"changed", GTK_SIGNAL_FUNC(port_dialog_tester), 
+		(gpointer)tester);
+
+ 	gtk_box_pack_start(GTK_BOX(vbox), tester, FALSE, TRUE, 0);
+
+	port_dialog_tester(GTK_COMBO(combo)->entry, tester);
+
 	vseparator = gtk_vseparator_new();
 	gtk_widget_show(vseparator);
 	gtk_box_pack_start(GTK_BOX(hbox), vseparator, FALSE, FALSE, 0);
@@ -578,17 +612,33 @@ void port_dialog() {
 	group = NULL;
 	label = gtk_label_new("Port:");
 	gtk_widget_show(label);
+#ifdef __NetBSD__
+	port0 = gtk_radio_button_new_with_label(NULL, "/dev/tty00 (COM1)");
+#else   
 	port0 = gtk_radio_button_new_with_label(NULL, "/dev/ttyS0 (COM1)");
+#endif
         gtk_widget_show(port0);
 	gtk_button_clicked(GTK_BUTTON(port0));
         group = gtk_radio_button_group(GTK_RADIO_BUTTON(port0));
+#ifdef __NetBSD__
+        port1 = gtk_radio_button_new_with_label(group, "/dev/tty01 (COM2)");
+#else   
         port1 = gtk_radio_button_new_with_label(group, "/dev/ttyS1 (COM2)");
+#endif
         gtk_widget_show(port1);
         group = gtk_radio_button_group(GTK_RADIO_BUTTON(port1));
+#ifdef __NetBSD__
+        port2 = gtk_radio_button_new_with_label(group, "/dev/tty02 (COM3)");
+#else   
         port2 = gtk_radio_button_new_with_label(group, "/dev/ttyS2 (COM3)");
+#endif
         gtk_widget_show(port2);
         group = gtk_radio_button_group(GTK_RADIO_BUTTON(port2));
+#ifdef __NetBSD__
+        port3 = gtk_radio_button_new_with_label(group, "/dev/tty03 (COM4)");
+#else   
         port3 = gtk_radio_button_new_with_label(group, "/dev/ttyS3 (COM4)");
+#endif
         gtk_widget_show(port3);
         group = gtk_radio_button_group(GTK_RADIO_BUTTON(port3));
         other = gtk_radio_button_new_with_label(group, "other");
@@ -627,6 +677,9 @@ void port_dialog() {
         gtk_box_pack_start(GTK_BOX(vbox), other, FALSE, FALSE, 0);
         gtk_box_pack_start(GTK_BOX(vbox), ent_other, FALSE, FALSE, 0);
 
+/*  	gtk_box_pack_start(GTK_BOX(vbox), betalabel, FALSE, FALSE, 0); */
+/*  	gtk_box_pack_start(GTK_BOX(vbox), tester, FALSE, FALSE, 0); */
+
         button = gtk_button_new_with_label("Save");
         gtk_widget_show(button);
         gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area),
@@ -690,7 +743,7 @@ gint load_config() {
 	FILE *conf;
 
         sprintf(fname, "%s/gphotorc", gphotoDir);
-        if (conf = fopen(fname, "r")) {
+        if ((conf = fopen(fname, "r"))) {
 		fgets(fname, 100, conf);
 		strncpy(serial_port, fname, strlen(fname)-1);
 		fgets(fname, 100, conf);
@@ -704,7 +757,11 @@ gint load_config() {
 	}
 
 	/* reset to defaults, and save */
+#ifdef __NetBSD__
+	sprintf(serial_port, "/dev/tty00");
+#else   
 	sprintf(serial_port, "/dev/ttyS0");
+#endif
 	sprintf(camera_model, "Browse Directory");
 	sprintf(post_process_script, "");
 	save_config();
@@ -717,7 +774,7 @@ void save_config() {
 	FILE *conf;
 
 	sprintf(gphotorc, "%s/gphotorc", gphotoDir);
-	if (conf = fopen(gphotorc, "w")) {
+	if ((conf = fopen(gphotorc, "w"))) {
 		fprintf(conf, "%s\n", serial_port);
 		fprintf(conf, "%s\n", camera_model);
 		fprintf(conf, "%s\n", post_process_script);
@@ -766,7 +823,7 @@ void usersmanual_dialog() {
 
 	sprintf(manual_filename, "%s/MANUAL", DOCDIR);
 
-	if (manual = fopen(manual_filename, "r")) {
+	if ((manual = fopen(manual_filename, "r"))) {
 		fseek(manual, 0, SEEK_END);
 		manual_size = ftell(manual);
 		rewind(manual);
@@ -1112,14 +1169,14 @@ void getpics (char *pictype) {
 			y++;
 			if ((strcmp("i", pictype) == 0) ||
 			    (strcmp("ti", pictype) == 0)) {
-				sprintf(status, "Getting Image #%i...", i);
+				sprintf(status, "Getting Image #%03i...", i);
 				update_status(status);
 				appendpic(i, 0, TRUE, NULL);
 			}
 			if ((strcmp("t", pictype) == 0) ||
 			    (strcmp("ti", pictype) == 0)) {			
 				appendpic(i, 1, TRUE, NULL);
-				sprintf(status, "Getting Thumbnail #%i...", i);
+				sprintf(status, "Getting Thumbnail #%03i...", i);
 				update_status(status);
 			}
 			gtk_toggle_button_set_state(
@@ -1253,7 +1310,7 @@ void save_dialog (GtkWidget *widget, gpointer data) {
 
 	x=1;
 	while (gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),x)!=NULL){
-		sprintf(filename, "%s-%i.jpg",
+		sprintf(filename, "%s-%03i.jpg",
 			gtk_file_selection_get_filename(
 			GTK_FILE_SELECTION(save_dialog_filew)), x);
 		save_opened_image(x, filename);
@@ -1347,7 +1404,7 @@ void print_pic () {
 	}
 
 	pid = getpid();
-	sprintf(fname, "%s/gphoto-%i-%i.jpg", gphotoDir, pid, currentPic);
+	sprintf(fname, "%s/gphoto-%i-%03i.jpg", gphotoDir, pid, currentPic);
 	gdk_imlib_save_image(node->imlibimage, fname,NULL);
 
 	update_status("Now spooling...");
