@@ -4,6 +4,7 @@
 #include <stdio.h> 
 #include <stdlib.h>
 #include <string.h>
+#include <signal.h>
 #include <fcntl.h>   
 #include <sys/stat.h> 
 #include <sys/types.h>
@@ -11,7 +12,10 @@
 #include <sched.h>
 #endif
 
+#define DECLARE_GLOBAL_VARS_IN_GPHOTO_H
 #include "gphoto.h"
+#undef DECLARE_GLOBAL_VARS_IN_GPHOTO_H
+
 #include "callbacks.h"
 #include "util.h"
 #include "cameras.h"
@@ -20,16 +24,12 @@
 #include "commandline.h"
 #include "developer_dialog.h"
 
-#include "splash.xpm"           /* Splash screen  */
-#include "post_processing_off.xpm"
+#include "icons/splash.xpm"           /* Splash screen  */
+#include "icons/post_processing_off.xpm"
 
 extern  struct Model cameras[];
 extern  GtkAccelGroup*  mainag;
-extern  int 	  command_line_mode;
-extern  char      *gphotoDir;		/* gPhoto directory		*/
-extern  char	  serial_port[20];	/* Serial port			*/
 
-        char	  camera_model[100];	/* Currently selected cam model */
 	GtkWidget *status_bar;		/* Main window status bar	*/
 	GtkWidget *library_name;	/* Main window library bar	*/
 	GtkWidget *notebook;            /* Main window Notebook		*/
@@ -50,6 +50,21 @@ extern  char	  serial_port[20];	/* Serial port			*/
 
 	char *filesel_cwd;
 
+void crash(int sig)
+{
+    char buddys[256];
+    sprintf(buddys,"bug-buddy --package=gphoto --package-ver=%s --pid=%d",VERSION, getpid());
+    fprintf(stdout,"gPhoto %s (built %s) process %d has crashed\n"
+	    "due to fatal errors.  Please send us a bug report!\n"
+	    "See $INSTALLPREFIX/doc/gphoto-%s/BUGS or\nhttp://gphoto.org/gphoto/bugs.html for details.\n",
+	    VERSION, __DATE__, getpid(), VERSION);
+    if (!system(buddys)) {
+	fprintf(stdout, "\nLaunching Gnome Bugbuddy...\n");
+        fprintf(stdout,"%s\n",buddys);
+    }
+    abort();
+}
+
 int main (int argc, char *argv[]) {
 
 	int has_rc=0;
@@ -70,6 +85,8 @@ int main (int argc, char *argv[]) {
 	char title[256];
 	char *envhome;
 
+	signal(SIGSEGV, crash);
+	
 	Thumbnails.next = NULL;
 	Images.next=NULL;
 
@@ -108,6 +125,15 @@ int main (int argc, char *argv[]) {
 	} else
 	    command_line_mode = 0;
 
+	fprintf(stdout,
+		"gPhoto %s (%s) - the GNU digital camera application\n",
+		VERSION, __DATE__);
+	fprintf(stdout,
+		"Copyright (C) 1998-2000 Scott Fritzinger <scottf@unr.edu>\n\n");
+	fprintf(stdout,
+		"Usage: gphoto [-h] [-c] [-n] [-s # filename] [-t # filename]\n");
+	fprintf(stdout, "              [-d #] [-p filename] [-l filename]\n");
+
 	gtk_init(&argc, &argv);
 #if 1 /* by fujisawa */
 	gdk_imlib_init();
